@@ -19,11 +19,16 @@ $my_graph->set(
 	y_label_skip => 4,
 
 	x_tick_number => 'auto',
+	x_label_skip => 2,
 
 	box_axis => 0,
 	line_width => 2,
 	x_label_position => 1/2,
 	r_margin => 15,
+
+	x_labels_vertical => 1,
+
+	transparent => 0,
 );
 
 $my_graph->set_legend('Thanks to Scott Prahl');
@@ -46,7 +51,7 @@ sub read_data
 		for (my $i = 0; $i <= $#row; $i++)
 		{
 			undef $row[$i] if ($row[$i] eq 'undef');
-			push @{$d[$i]}, $row[$i];
+			unshift @{$d[$i]}, $row[$i];
 		}
 	}
 
